@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Maximum Entropy Classifiers
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Dmitry Chichkov <dchichkov@gmail.com> (TypedMaxentFeatureEncoding)
 # URL: <http://nltk.org/>
@@ -1287,7 +1287,7 @@ def calculate_deltas(
     nftranspose,
     encoding,
 ):
-    """
+    r"""
     Calculate the update values for the classifier weights for
     this iteration of IIS.  These update weights are the value of
     ``delta`` that solves the equation::
@@ -1452,7 +1452,7 @@ def train_maxent_classifier_with_megam(
             )
         os.close(fd)
     except (OSError, IOError, ValueError) as e:
-        raise ValueError("Error while creating megam training file: %s" % e)
+        raise ValueError("Error while creating megam training file: %s" % e) from e
 
     # Run megam on the training file.
     options = []
