@@ -1,7 +1,7 @@
 # encoding: utf-8
 # Natural Language Toolkit: Senna Interface
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Rami Al-Rfou' <ralrfou@cs.stonybrook.edu>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -166,13 +166,13 @@ class Senna(TaggerI):
                 result[tag] = tags[map_[tag]].strip()
             try:
                 result["word"] = sentences[sentence_index][token_index]
-            except IndexError:
+            except IndexError as e:
                 raise IndexError(
                     "Misalignment error occurred at sentence number %d. Possible reason"
                     " is that the sentence size exceeded the maximum size. Check the "
                     "documentation of Senna class for more information."
                     % sentence_index
-                )
+                ) from e
             tagged_sentences[-1].append(result)
             token_index += 1
         return tagged_sentences
@@ -180,9 +180,9 @@ class Senna(TaggerI):
 
 # skip doctests if Senna is not installed
 def setup_module(module):
-    from nose import SkipTest
+    import pytest
 
     try:
         tagger = Senna("/usr/share/senna-v3.0", ["pos", "chk", "ner"])
     except OSError:
-        raise SkipTest("Senna executable not found")
+        pytest.skip("Senna executable not found")
