@@ -160,7 +160,7 @@ class TimitCorpusReader(CorpusReader):
         """
         # Ensure that wave files don't get treated as unicode data:
         if isinstance(encoding, str):
-            encoding = [(".*\.wav", None), (".*", encoding)]
+            encoding = [(r".*\.wav", None), (".*", encoding)]
 
         CorpusReader.__init__(
             self, root, find_corpus_fileids(root, self._FILE_RE), encoding=encoding
