@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Corpus Reader Utilities
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>
 #         Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
@@ -170,7 +170,9 @@ class StreamBackedCorpusView(AbstractLazySequence):
             else:
                 self._eofpos = os.stat(self._fileid).st_size
         except Exception as exc:
-            raise ValueError("Unable to open or access %r -- %s" % (fileid, exc))
+            raise ValueError(
+                "Unable to open or access %r -- %s" % (fileid, exc)
+            ) from exc
 
         # Maintain a cache of the most recently read block, to
         # increase efficiency of random access.
@@ -253,8 +255,8 @@ class StreamBackedCorpusView(AbstractLazySequence):
             # Use iterate_from to extract it.
             try:
                 return next(self.iterate_from(i))
-            except StopIteration:
-                raise IndexError("index out of range")
+            except StopIteration as e:
+                raise IndexError("index out of range") from e
 
     # If we wanted to be thread-safe, then this method would need to
     # do some locking.
@@ -556,7 +558,7 @@ class PickleCorpusView(StreamBackedCorpusView):
             output_file.close()
             return PickleCorpusView(output_file_name, delete_on_gc)
         except (OSError, IOError) as e:
-            raise ValueError("Error while creating temp file: %s" % e)
+            raise ValueError("Error while creating temp file: %s" % e) from e
 
 
 ######################################################################
@@ -622,7 +624,7 @@ def read_alignedsent_block(stream):
         # Other line:
         else:
             s += line
-            if re.match("^\d+-\d+", line) is not None:
+            if re.match(r"^\d+-\d+", line) is not None:
                 return [s]
 
 
@@ -846,7 +848,7 @@ def tagged_treebank_para_block_reader(stream):
     while True:
         line = stream.readline()
         # End of paragraph:
-        if re.match("======+\s*$", line):
+        if re.match(r"======+\s*$", line):
             if para.strip():
                 return [para]
         # End of file:
