@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Verbnet Corpus Reader
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -11,14 +11,11 @@ An NLTK interface to the VerbNet verb lexicon
 For details about VerbNet see:
 https://verbs.colorado.edu/~mpalmer/projects/verbnet.html
 """
-from __future__ import unicode_literals
 
 import re
 import textwrap
 from collections import defaultdict
 
-from six import string_types
-
 from nltk.corpus.reader.xmldocs import XMLCorpusReader
 
 
@@ -60,10 +57,10 @@ class VerbnetCorpusReader(XMLCorpusReader):
         # runs 2-30 times faster.
         self._quick_index()
 
-    _LONGID_RE = re.compile(r'([^\-\.]*)-([\d+.\-]+)$')
+    _LONGID_RE = re.compile(r"([^\-\.]*)-([\d+.\-]+)$")
     """Regular expression that matches (and decomposes) longids"""
 
-    _SHORTID_RE = re.compile(r'[\d+.\-]+$')
+    _SHORTID_RE = re.compile(r"[\d+.\-]+$")
     """Regular expression that matches shortids"""
 
     _INDEX_RE = re.compile(
@@ -81,9 +78,9 @@ class VerbnetCorpusReader(XMLCorpusReader):
             return sorted(self._lemma_to_class.keys())
         else:
             # [xx] should this include subclass members?
-            if isinstance(vnclass, string_types):
+            if isinstance(vnclass, str):
                 vnclass = self.vnclass(vnclass)
-            return [member.get('name') for member in vnclass.findall('MEMBERS/MEMBER')]
+            return [member.get("name") for member in vnclass.findall("MEMBERS/MEMBER")]
 
     def wordnetids(self, vnclass=None):
         """
@@ -94,12 +91,12 @@ class VerbnetCorpusReader(XMLCorpusReader):
             return sorted(self._wordnet_to_class.keys())
         else:
             # [xx] should this include subclass members?
-            if isinstance(vnclass, string_types):
+            if isinstance(vnclass, str):
                 vnclass = self.vnclass(vnclass)
             return sum(
                 [
-                    member.get('wn', '').split()
-                    for member in vnclass.findall('MEMBERS/MEMBER')
+                    member.get("wn", "").split()
+                    for member in vnclass.findall("MEMBERS/MEMBER")
                 ],
                 [],
             )
@@ -126,8 +123,8 @@ class VerbnetCorpusReader(XMLCorpusReader):
         elif classid is not None:
             xmltree = self.vnclass(classid)
             return [
-                subclass.get('ID')
-                for subclass in xmltree.findall('SUBCLASSES/VNSUBCLASS')
+                subclass.get("ID")
+                for subclass in xmltree.findall("SUBCLASSES/VNSUBCLASS")
             ]
         else:
             return sorted(self._class_to_fileid.keys())
@@ -153,17 +150,17 @@ class VerbnetCorpusReader(XMLCorpusReader):
         if classid in self._class_to_fileid:
             fileid = self._class_to_fileid[self.longid(classid)]
             tree = self.xml(fileid)
-            if classid == tree.get('ID'):
+            if classid == tree.get("ID"):
                 return tree
             else:
-                for subclass in tree.findall('.//VNSUBCLASS'):
-                    if classid == subclass.get('ID'):
+                for subclass in tree.findall(".//VNSUBCLASS"):
+                    if classid == subclass.get("ID"):
                         return subclass
                 else:
                     assert False  # we saw it during _index()!
 
         else:
-            raise ValueError('Unknown identifier {}'.format(fileid_or_classid))
+            raise ValueError("Unknown identifier {}".format(fileid_or_classid))
 
     def fileids(self, vnclass_ids=None):
         """
@@ -173,7 +170,7 @@ class VerbnetCorpusReader(XMLCorpusReader):
         """
         if vnclass_ids is None:
             return self._fileids
-        elif isinstance(vnclass_ids, string_types):
+        elif isinstance(vnclass_ids, str):
             return [self._class_to_fileid[self.longid(vnclass_ids)]]
         else:
             return [
@@ -194,17 +191,17 @@ class VerbnetCorpusReader(XMLCorpusReader):
             containing the xml contents of a VerbNet class.
         :return: frames - a list of frame dictionaries
         """
-        if isinstance(vnclass, string_types):
+        if isinstance(vnclass, str):
             vnclass = self.vnclass(vnclass)
         frames = []
-        vnframes = vnclass.findall('FRAMES/FRAME')
+        vnframes = vnclass.findall("FRAMES/FRAME")
         for vnframe in vnframes:
             frames.append(
                 {
-                    'example': self._get_example_within_frame(vnframe),
-                    'description': self._get_description_within_frame(vnframe),
-                    'syntax': self._get_syntactic_list_within_frame(vnframe),
-                    'semantics': self._get_semantics_within_frame(vnframe),
+                    "example": self._get_example_within_frame(vnframe),
+                    "description": self._get_description_within_frame(vnframe),
+                    "syntax": self._get_syntactic_list_within_frame(vnframe),
+                    "semantics": self._get_semantics_within_frame(vnframe),
                 }
             )
         return frames
@@ -219,11 +216,11 @@ class VerbnetCorpusReader(XMLCorpusReader):
             containing the xml contents of a VerbNet class.
         :return: list of subclasses
         """
-        if isinstance(vnclass, string_types):
+        if isinstance(vnclass, str):
             vnclass = self.vnclass(vnclass)
 
         subclasses = [
-            subclass.get('ID') for subclass in vnclass.findall('SUBCLASSES/VNSUBCLASS')
+            subclass.get("ID") for subclass in vnclass.findall("SUBCLASSES/VNSUBCLASS")
         ]
         return subclasses
 
@@ -238,17 +235,17 @@ class VerbnetCorpusReader(XMLCorpusReader):
             containing the xml contents of a VerbNet class.
         :return: themroles: A list of thematic roles in the VerbNet class
         """
-        if isinstance(vnclass, string_types):
+        if isinstance(vnclass, str):
             vnclass = self.vnclass(vnclass)
 
         themroles = []
-        for trole in vnclass.findall('THEMROLES/THEMROLE'):
+        for trole in vnclass.findall("THEMROLES/THEMROLE"):
             themroles.append(
                 {
-                    'type': trole.get('type'),
-                    'modifiers': [
-                        {'value': restr.get('Value'), 'type': restr.get('type')}
-                        for restr in trole.findall('SELRESTRS/SELRESTR')
+                    "type": trole.get("type"),
+                    "modifiers": [
+                        {"value": restr.get("Value"), "type": restr.get("type")}
+                        for restr in trole.findall("SELRESTRS/SELRESTR")
                     ],
                 }
             )
@@ -262,23 +259,23 @@ class VerbnetCorpusReader(XMLCorpusReader):
         """
         Initialize the indexes ``_lemma_to_class``,
         ``_wordnet_to_class``, and ``_class_to_fileid`` by scanning
-        through the corpus fileids.  This is fast with cElementTree
-        (<0.1 secs), but quite slow (>10 secs) with the python
-        implementation of ElementTree.
+        through the corpus fileids.  This is fast if ElementTree
+        uses the C implementation (<0.1 secs), but quite slow (>10 secs)
+        if only the python implementation is available.
         """
         for fileid in self._fileids:
             self._index_helper(self.xml(fileid), fileid)
 
     def _index_helper(self, xmltree, fileid):
         """Helper for ``_index()``"""
-        vnclass = xmltree.get('ID')
+        vnclass = xmltree.get("ID")
         self._class_to_fileid[vnclass] = fileid
         self._shortid_to_longid[self.shortid(vnclass)] = vnclass
-        for member in xmltree.findall('MEMBERS/MEMBER'):
-            self._lemma_to_class[member.get('name')].append(vnclass)
-            for wn in member.get('wn', '').split():
+        for member in xmltree.findall("MEMBERS/MEMBER"):
+            self._lemma_to_class[member.get("name")].append(vnclass)
+            for wn in member.get("wn", "").split():
                 self._wordnet_to_class[wn].append(vnclass)
-        for subclass in xmltree.findall('SUBCLASSES/VNSUBCLASS'):
+        for subclass in xmltree.findall("SUBCLASSES/VNSUBCLASS"):
             self._index_helper(subclass, fileid)
 
     def _quick_index(self):
@@ -288,8 +285,8 @@ class VerbnetCorpusReader(XMLCorpusReader):
         through the corpus fileids.  This doesn't do proper xml parsing,
         but is good enough to find everything in the standard VerbNet
         corpus -- and it runs about 30 times faster than xml parsing
-        (with the python ElementTree; only 2-3 times faster with
-        cElementTree).
+        (with the python ElementTree; only 2-3 times faster
+        if ElementTree uses the C implementation).
         """
         # nb: if we got rid of wordnet_to_class, this would run 2-3
         # times faster.
@@ -308,7 +305,7 @@ class VerbnetCorpusReader(XMLCorpusReader):
                     vnclass = groups[2]  # for <MEMBER> elts.
                     self._shortid_to_longid[self.shortid(vnclass)] = vnclass
                 else:
-                    assert False, 'unexpected match condition'
+                    assert False, "unexpected match condition"
 
     ######################################################################
     # { Identifier conversion
@@ -323,11 +320,11 @@ class VerbnetCorpusReader(XMLCorpusReader):
         if self._LONGID_RE.match(shortid):
             return shortid  # it's already a longid.
         elif not self._SHORTID_RE.match(shortid):
-            raise ValueError('vnclass identifier %r not found' % shortid)
+            raise ValueError("vnclass identifier %r not found" % shortid)
         try:
             return self._shortid_to_longid[shortid]
-        except KeyError:
-            raise ValueError('vnclass identifier %r not found' % shortid)
+        except KeyError as e:
+            raise ValueError("vnclass identifier %r not found" % shortid) from e
 
     def shortid(self, longid):
         """Returns shortid of a VerbNet class
@@ -341,7 +338,7 @@ class VerbnetCorpusReader(XMLCorpusReader):
         if m:
             return m.group(2)
         else:
-            raise ValueError('vnclass identifier %r not found' % longid)
+            raise ValueError("vnclass identifier %r not found" % longid)
 
     ######################################################################
     # { Frame access utility functions
@@ -360,13 +357,13 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :return: semantics: semantics dictionary
         """
         semantics_within_single_frame = []
-        for pred in vnframe.findall('SEMANTICS/PRED'):
+        for pred in vnframe.findall("SEMANTICS/PRED"):
             arguments = [
-                {'type': arg.get('type'), 'value': arg.get('value')}
-                for arg in pred.findall('ARGS/ARG')
+                {"type": arg.get("type"), "value": arg.get("value")}
+                for arg in pred.findall("ARGS/ARG")
             ]
             semantics_within_single_frame.append(
-                {'predicate_value': pred.get('value'), 'arguments': arguments}
+                {"predicate_value": pred.get("value"), "arguments": arguments}
             )
         return semantics_within_single_frame
 
@@ -379,7 +376,7 @@ class VerbnetCorpusReader(XMLCorpusReader):
             a VerbNet frame.
         :return: example_text: The example sentence for this particular frame
         """
-        example_element = vnframe.find('EXAMPLES/EXAMPLE')
+        example_element = vnframe.find("EXAMPLES/EXAMPLE")
         if example_element is not None:
             example_text = example_element.text
         else:
@@ -396,10 +393,10 @@ class VerbnetCorpusReader(XMLCorpusReader):
             a VerbNet frame.
         :return: description: a description dictionary with members - primary and secondary
         """
-        description_element = vnframe.find('DESCRIPTION')
+        description_element = vnframe.find("DESCRIPTION")
         return {
-            'primary': description_element.attrib['primary'],
-            'secondary': description_element.get('secondary', ''),
+            "primary": description_element.attrib["primary"],
+            "secondary": description_element.get("secondary", ""),
         }
 
     def _get_syntactic_list_within_frame(self, vnframe):
@@ -415,20 +412,20 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :return: syntax_within_single_frame
         """
         syntax_within_single_frame = []
-        for elt in vnframe.find('SYNTAX'):
+        for elt in vnframe.find("SYNTAX"):
             pos_tag = elt.tag
             modifiers = dict()
-            modifiers['value'] = elt.get('value') if 'value' in elt.attrib else ""
-            modifiers['selrestrs'] = [
-                {'value': restr.get('Value'), 'type': restr.get('type')}
-                for restr in elt.findall('SELRESTRS/SELRESTR')
+            modifiers["value"] = elt.get("value") if "value" in elt.attrib else ""
+            modifiers["selrestrs"] = [
+                {"value": restr.get("Value"), "type": restr.get("type")}
+                for restr in elt.findall("SELRESTRS/SELRESTR")
             ]
-            modifiers['synrestrs'] = [
-                {'value': restr.get('Value'), 'type': restr.get('type')}
-                for restr in elt.findall('SYNRESTRS/SYNRESTR')
+            modifiers["synrestrs"] = [
+                {"value": restr.get("Value"), "type": restr.get("type")}
+                for restr in elt.findall("SYNRESTRS/SYNRESTR")
             ]
             syntax_within_single_frame.append(
-                {'pos_tag': pos_tag, 'modifiers': modifiers}
+                {"pos_tag": pos_tag, "modifiers": modifiers}
             )
         return syntax_within_single_frame
 
@@ -445,19 +442,19 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :param vnclass: A VerbNet class identifier; or an ElementTree
         containing the xml contents of a VerbNet class.
         """
-        if isinstance(vnclass, string_types):
+        if isinstance(vnclass, str):
             vnclass = self.vnclass(vnclass)
 
-        s = vnclass.get('ID') + '\n'
-        s += self.pprint_subclasses(vnclass, indent='  ') + '\n'
-        s += self.pprint_members(vnclass, indent='  ') + '\n'
-        s += '  Thematic roles:\n'
-        s += self.pprint_themroles(vnclass, indent='    ') + '\n'
-        s += '  Frames:\n'
-        s += self.pprint_frames(vnclass, indent='    ')
+        s = vnclass.get("ID") + "\n"
+        s += self.pprint_subclasses(vnclass, indent="  ") + "\n"
+        s += self.pprint_members(vnclass, indent="  ") + "\n"
+        s += "  Thematic roles:\n"
+        s += self.pprint_themroles(vnclass, indent="    ") + "\n"
+        s += "  Frames:\n"
+        s += self.pprint_frames(vnclass, indent="    ")
         return s
 
-    def pprint_subclasses(self, vnclass, indent=''):
+    def pprint_subclasses(self, vnclass, indent=""):
         """Returns pretty printed version of subclasses of VerbNet class
 
         Return a string containing a pretty-printed representation of
@@ -466,18 +463,18 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :param vnclass: A VerbNet class identifier; or an ElementTree
             containing the xml contents of a VerbNet class.
         """
-        if isinstance(vnclass, string_types):
+        if isinstance(vnclass, str):
             vnclass = self.vnclass(vnclass)
 
         subclasses = self.subclasses(vnclass)
         if not subclasses:
-            subclasses = ['(none)']
-        s = 'Subclasses: ' + ' '.join(subclasses)
+            subclasses = ["(none)"]
+        s = "Subclasses: " + " ".join(subclasses)
         return textwrap.fill(
-            s, 70, initial_indent=indent, subsequent_indent=indent + '  '
+            s, 70, initial_indent=indent, subsequent_indent=indent + "  "
         )
 
-    def pprint_members(self, vnclass, indent=''):
+    def pprint_members(self, vnclass, indent=""):
         """Returns pretty printed version of members in a VerbNet class
 
         Return a string containing a pretty-printed representation of
@@ -486,18 +483,18 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :param vnclass: A VerbNet class identifier; or an ElementTree
             containing the xml contents of a VerbNet class.
         """
-        if isinstance(vnclass, string_types):
+        if isinstance(vnclass, str):
             vnclass = self.vnclass(vnclass)
 
         members = self.lemmas(vnclass)
         if not members:
-            members = ['(none)']
-        s = 'Members: ' + ' '.join(members)
+            members = ["(none)"]
+        s = "Members: " + " ".join(members)
         return textwrap.fill(
-            s, 70, initial_indent=indent, subsequent_indent=indent + '  '
+            s, 70, initial_indent=indent, subsequent_indent=indent + "  "
         )
 
-    def pprint_themroles(self, vnclass, indent=''):
+    def pprint_themroles(self, vnclass, indent=""):
         """Returns pretty printed version of thematic roles in a VerbNet class
 
         Return a string containing a pretty-printed representation of
@@ -506,22 +503,22 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :param vnclass: A VerbNet class identifier; or an ElementTree
             containing the xml contents of a VerbNet class.
         """
-        if isinstance(vnclass, string_types):
+        if isinstance(vnclass, str):
             vnclass = self.vnclass(vnclass)
 
         pieces = []
         for themrole in self.themroles(vnclass):
-            piece = indent + '* ' + themrole.get('type')
+            piece = indent + "* " + themrole.get("type")
             modifiers = [
-                modifier['value'] + modifier['type']
-                for modifier in themrole['modifiers']
+                modifier["value"] + modifier["type"]
+                for modifier in themrole["modifiers"]
             ]
             if modifiers:
-                piece += '[{}]'.format(' '.join(modifiers))
+                piece += "[{}]".format(" ".join(modifiers))
             pieces.append(piece)
-        return '\n'.join(pieces)
+        return "\n".join(pieces)
 
-    def pprint_frames(self, vnclass, indent=''):
+    def pprint_frames(self, vnclass, indent=""):
         """Returns pretty version of all frames in a VerbNet class
 
         Return a string containing a pretty-printed representation of
@@ -530,14 +527,14 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :param vnclass: A VerbNet class identifier; or an ElementTree
             containing the xml contents of a VerbNet class.
         """
-        if isinstance(vnclass, string_types):
+        if isinstance(vnclass, str):
             vnclass = self.vnclass(vnclass)
         pieces = []
         for vnframe in self.frames(vnclass):
             pieces.append(self._pprint_single_frame(vnframe, indent))
-        return '\n'.join(pieces)
+        return "\n".join(pieces)
 
-    def _pprint_single_frame(self, vnframe, indent=''):
+    def _pprint_single_frame(self, vnframe, indent=""):
         """Returns pretty printed version of a single frame in a VerbNet class
 
         Returns a string containing a pretty-printed representation of
@@ -546,16 +543,16 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :param vnframe: An ElementTree containing the xml contents of
             a VerbNet frame.
         """
-        frame_string = self._pprint_description_within_frame(vnframe, indent) + '\n'
-        frame_string += self._pprint_example_within_frame(vnframe, indent + ' ') + '\n'
+        frame_string = self._pprint_description_within_frame(vnframe, indent) + "\n"
+        frame_string += self._pprint_example_within_frame(vnframe, indent + " ") + "\n"
         frame_string += (
-            self._pprint_syntax_within_frame(vnframe, indent + '  Syntax: ') + '\n'
+            self._pprint_syntax_within_frame(vnframe, indent + "  Syntax: ") + "\n"
         )
-        frame_string += indent + '  Semantics:\n'
-        frame_string += self._pprint_semantics_within_frame(vnframe, indent + '    ')
+        frame_string += indent + "  Semantics:\n"
+        frame_string += self._pprint_semantics_within_frame(vnframe, indent + "    ")
         return frame_string
 
-    def _pprint_example_within_frame(self, vnframe, indent=''):
+    def _pprint_example_within_frame(self, vnframe, indent=""):
         """Returns pretty printed version of example within frame in a VerbNet class
 
         Return a string containing a pretty-printed representation of
@@ -564,10 +561,10 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :param vnframe: An ElementTree containing the xml contents of
             a Verbnet frame.
         """
-        if vnframe['example']:
-            return indent + ' Example: ' + vnframe['example']
+        if vnframe["example"]:
+            return indent + " Example: " + vnframe["example"]
 
-    def _pprint_description_within_frame(self, vnframe, indent=''):
+    def _pprint_description_within_frame(self, vnframe, indent=""):
         """Returns pretty printed version of a VerbNet frame description
 
         Return a string containing a pretty-printed representation of
@@ -576,12 +573,12 @@ class VerbnetCorpusReader(XMLCorpusReader):
         :param vnframe: An ElementTree containing the xml contents of
             a VerbNet frame.
         """
-        description = indent + vnframe['description']['primary']
-        if vnframe['description']['secondary']:
-            description += ' ({})'.format(vnframe['description']['secondary'])
+        description = indent + vnframe["description"]["primary"]
+        if vnframe["description"]["secondary"]:
+            description += " ({})".format(vnframe["description"]["secondary"])
         return description
 
-    def _pprint_syntax_within_frame(self, vnframe, indent=''):
+    def _pprint_syntax_within_frame(self, vnframe, indent=""):
         """Returns pretty printed version of syntax within a frame in a VerbNet class
 
         Return a string containing a pretty-printed representation of
@@ -591,25 +588,25 @@ class VerbnetCorpusReader(XMLCorpusReader):
             a VerbNet frame.
         """
         pieces = []
-        for element in vnframe['syntax']:
-            piece = element['pos_tag']
+        for element in vnframe["syntax"]:
+            piece = element["pos_tag"]
             modifier_list = []
-            if 'value' in element['modifiers'] and element['modifiers']['value']:
-                modifier_list.append(element['modifiers']['value'])
+            if "value" in element["modifiers"] and element["modifiers"]["value"]:
+                modifier_list.append(element["modifiers"]["value"])
             modifier_list += [
-                '{}{}'.format(restr['value'], restr['type'])
+                "{}{}".format(restr["value"], restr["type"])
                 for restr in (
-                    element['modifiers']['selrestrs']
-                    + element['modifiers']['synrestrs']
+                    element["modifiers"]["selrestrs"]
+                    + element["modifiers"]["synrestrs"]
                 )
             ]
             if modifier_list:
-                piece += '[{}]'.format(' '.join(modifier_list))
+                piece += "[{}]".format(" ".join(modifier_list))
             pieces.append(piece)
 
-        return indent + ' '.join(pieces)
+        return indent + " ".join(pieces)
 
-    def _pprint_semantics_within_frame(self, vnframe, indent=''):
+    def _pprint_semantics_within_frame(self, vnframe, indent=""):
         """Returns a pretty printed version of semantics within frame in a VerbNet class
 
         Return a string containing a pretty-printed representation of
@@ -619,9 +616,9 @@ class VerbnetCorpusReader(XMLCorpusReader):
             a VerbNet frame.
         """
         pieces = []
-        for predicate in vnframe['semantics']:
-            arguments = [argument['value'] for argument in predicate['arguments']]
+        for predicate in vnframe["semantics"]:
+            arguments = [argument["value"] for argument in predicate["arguments"]]
             pieces.append(
-                '{}({})'.format(predicate['predicate_value'], ', '.join(arguments))
+                "{}({})".format(predicate["predicate_value"], ", ".join(arguments))
             )
-        return '\n'.join('{}* {}'.format(indent, piece) for piece in pieces)
+        return "\n".join("{}* {}".format(indent, piece) for piece in pieces)
