@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Utility functions
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -33,8 +33,7 @@ to a local file.
 
 import functools
 import textwrap
-import io
-from io import BytesIO
+from io import BytesIO, TextIOWrapper
 import os
 import re
 import sys
@@ -52,8 +51,7 @@ try:
 except ImportError:
     from zlib import Z_FINISH as FLUSH
 
-# this import should be more specific:
-import nltk
+from nltk import grammar, sem
 from nltk.compat import py3_data, add_py3_data
 from nltk.internals import deprecated
 
@@ -116,7 +114,7 @@ def gzip_open_unicode(
 ):
     if fileobj is None:
         fileobj = GzipFile(filename, mode, compresslevel, fileobj)
-    return io.TextIOWrapper(fileobj, encoding, errors, newline)
+    return TextIOWrapper(fileobj, encoding, errors, newline)
 
 
 def split_resource_url(resource_url):
@@ -371,7 +369,7 @@ class GzipFileSystemPathPointer(FileSystemPathPointer):
     """
 
     def open(self, encoding=None):
-        stream = GzipFile(self._path, "rb")    
+        stream = GzipFile(self._path, "rb")
         if encoding:
             stream = SeekableUnicodeStreamReader(stream, encoding)
         return stream
@@ -403,7 +401,7 @@ class ZipFilePathPointer(PathPointer):
 
             try:
                 zipfile.getinfo(entry)
-            except Exception:
+            except Exception as e:
                 # Sometimes directories aren't explicitly listed in
                 # the zip file.  So if `entry` is a directory name,
                 # then check if the zipfile contains any files that
@@ -416,7 +414,7 @@ class ZipFilePathPointer(PathPointer):
                     # Otherwise, complain.
                     raise IOError(
                         "Zipfile %r does not contain %r" % (zipfile.filename, entry)
-                    )
+                    ) from e
         self._zipfile = zipfile
         self._entry = entry
 
@@ -782,28 +780,28 @@ def load(
         if format == "text":
             resource_val = string_data
         elif format == "cfg":
-            resource_val = nltk.grammar.CFG.fromstring(string_data, encoding=encoding)
+            resource_val = grammar.CFG.fromstring(string_data, encoding=encoding)
         elif format == "pcfg":
-            resource_val = nltk.grammar.PCFG.fromstring(string_data, encoding=encoding)
+            resource_val = grammar.PCFG.fromstring(string_data, encoding=encoding)
         elif format == "fcfg":
-            resource_val = nltk.grammar.FeatureGrammar.fromstring(
+            resource_val = grammar.FeatureGrammar.fromstring(
                 string_data,
                 logic_parser=logic_parser,
                 fstruct_reader=fstruct_reader,
                 encoding=encoding,
             )
         elif format == "fol":
-            resource_val = nltk.sem.read_logic(
+            resource_val = sem.read_logic(
                 string_data,
-                logic_parser=nltk.sem.logic.LogicParser(),
+                logic_parser=sem.logic.LogicParser(),
                 encoding=encoding,
             )
         elif format == "logic":
-            resource_val = nltk.sem.read_logic(
+            resource_val = sem.read_logic(
                 string_data, logic_parser=logic_parser, encoding=encoding
             )
         elif format == "val":
-            resource_val = nltk.sem.read_valuation(string_data, encoding=encoding)
+            resource_val = sem.read_valuation(string_data, encoding=encoding)
         else:
             raise AssertionError(
                 "Internal NLTK error: Format %s isn't "
@@ -887,7 +885,7 @@ def _open(resource_url):
 ######################################################################
 
 
-class LazyLoader(object):
+class LazyLoader:
     @py3_data
     def __init__(self, _path):
         self._path = _path
@@ -963,11 +961,11 @@ class OpenOnDemandZipFile(zipfile.ZipFile):
 
 
 ######################################################################
-# { Seekable Unicode Stream Reader
+# Seekable Unicode Stream Reader
 ######################################################################
 
 
-class SeekableUnicodeStreamReader(object):
+class SeekableUnicodeStreamReader:
     """
     A stream reader that automatically encodes the source byte stream
     into unicode (like ``codecs.StreamReader``); but still supports the
