@@ -2,18 +2,14 @@
 #
 # Author: Dan Garrette <dhgarrette@gmail.com>
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
-from __future__ import print_function, unicode_literals
 
 import operator
 from functools import reduce
 from itertools import chain
 
-from six import string_types
-
-from nltk.compat import python_2_unicode_compatible
 from nltk.sem.logic import (
     APP,
     AbstractVariableExpression,
@@ -44,8 +40,8 @@ from nltk.sem.logic import (
 
 # Import Tkinter-based modules if they are available
 try:
-    from six.moves.tkinter import Canvas, Tk
-    from six.moves.tkinter_font import Font
+    from tkinter import Canvas, Tk
+    from tkinter.font import Font
     from nltk.util import in_idle
 
 except ImportError:
@@ -54,12 +50,12 @@ except ImportError:
 
 
 class DrtTokens(Tokens):
-    DRS = 'DRS'
-    DRS_CONC = '+'
-    PRONOUN = 'PRO'
-    OPEN_BRACKET = '['
-    CLOSE_BRACKET = ']'
-    COLON = ':'
+    DRS = "DRS"
+    DRS_CONC = "+"
+    PRONOUN = "PRO"
+    OPEN_BRACKET = "["
+    CLOSE_BRACKET = "]"
+    COLON = ":"
 
     PUNCT = [DRS_CONC, OPEN_BRACKET, CLOSE_BRACKET, COLON]
 
@@ -139,7 +135,7 @@ class DrtParser(LogicParser):
             # Support expressions like: DRS([x y],C) == DRS([x,y],C)
             if refs and self.token(0) == DrtTokens.COMMA:
                 self.token()  # swallow the comma
-            refs.append(self.get_next_token_variable('quantified'))
+            refs.append(self.get_next_token_variable("quantified"))
         self.assertNextToken(DrtTokens.CLOSE_BRACKET)
         return refs
 
@@ -156,7 +152,7 @@ class DrtParser(LogicParser):
 
     def handle_prop(self, tok, context):
         variable = self.make_VariableExpression(tok)
-        self.assertNextToken(':')
+        self.assertNextToken(":")
         drs = self.process_next_expression(DrtTokens.COLON)
         return DrtProposition(variable, drs)
 
@@ -179,7 +175,7 @@ class DrtParser(LogicParser):
                     return DRS(first.refs, first.conds, second)
                 if isinstance(first, DrtConcatenation):
                     return DrtConcatenation(first.first, first.second, second)
-                raise Exception('Antecedent of implication must be a DRS')
+                raise Exception("Antecedent of implication must be a DRS")
 
             return make_imp_expression
         else:
@@ -229,7 +225,7 @@ class DrtExpression(object):
             return DRS(self.refs, self.conds, other)
         if isinstance(self, DrtConcatenation):
             return DrtConcatenation(self.first, self.second, other)
-        raise Exception('Antecedent of implication must be a DRS')
+        raise Exception("Antecedent of implication must be a DRS")
 
     def equiv(self, other, prover=None):
         """
@@ -292,7 +288,7 @@ class DrtExpression(object):
         Draw the DRS
         :return: the pretty print string
         """
-        return '\n'.join(self._pretty())
+        return "\n".join(self._pretty())
 
     def pretty_print(self):
         print(self.pretty_format())
@@ -301,7 +297,6 @@ class DrtExpression(object):
         DrsDrawer(self).draw()
 
 
-@python_2_unicode_compatible
 class DRS(DrtExpression, Expression):
     """A Discourse Representation Structure."""
 
@@ -388,7 +383,7 @@ class DRS(DrtExpression, Expression):
         """:see: AbstractExpression.get_refs()"""
         if recursive:
             conds_refs = self.refs + list(
-                chain(*(c.get_refs(True) for c in self.conds))
+                chain.from_iterable(c.get_refs(True) for c in self.conds)
             )
             if self.consequent:
                 conds_refs.extend(self.consequent.get_refs(True))
@@ -469,7 +464,7 @@ class DRS(DrtExpression, Expression):
             return accum
 
     def _pretty(self):
-        refs_line = ' '.join(self._order_ref_strings(self.refs))
+        refs_line = " ".join(self._order_ref_strings(self.refs))
 
         cond_lines = [
             cond
@@ -481,12 +476,12 @@ class DRS(DrtExpression, Expression):
         length = max([len(refs_line)] + list(map(len, cond_lines)))
         drs = (
             [
-                ' _' + '_' * length + '_ ',
-                '| ' + refs_line.ljust(length) + ' |',
-                '|-' + '-' * length + '-|',
+                " _" + "_" * length + "_ ",
+                "| " + refs_line.ljust(length) + " |",
+                "|-" + "-" * length + "-|",
             ]
-            + ['| ' + line.ljust(length) + ' |' for line in cond_lines]
-            + ['|_' + '_' * length + '_|']
+            + ["| " + line.ljust(length) + " |" for line in cond_lines]
+            + ["|_" + "_" * length + "_|"]
         )
         if self.consequent:
             return DrtBinaryExpression._assemble_pretty(
@@ -540,17 +535,17 @@ class DRS(DrtExpression, Expression):
     __hash__ = Expression.__hash__
 
     def __str__(self):
-        drs = '([%s],[%s])' % (
-            ','.join(self._order_ref_strings(self.refs)),
-            ', '.join("%s" % cond for cond in self.conds),
+        drs = "([%s],[%s])" % (
+            ",".join(self._order_ref_strings(self.refs)),
+            ", ".join("%s" % cond for cond in self.conds),
         )  # map(str, self.conds)))
         if self.consequent:
             return (
                 DrtTokens.OPEN
                 + drs
-                + ' '
+                + " "
                 + DrtTokens.IMP
-                + ' '
+                + " "
                 + "%s" % self.consequent
                 + DrtTokens.CLOSE
             )
@@ -582,7 +577,7 @@ class DrtAbstractVariableExpression(DrtExpression, AbstractVariableExpression):
 
     def _pretty(self):
         s = "%s" % self
-        blank = ' ' * len(s)
+        blank = " " * len(s)
         return [blank, blank, s, blank]
 
     def eliminate_equality(self):
@@ -611,7 +606,6 @@ class DrtConstantExpression(DrtAbstractVariableExpression, ConstantExpression):
     pass
 
 
-@python_2_unicode_compatible
 class DrtProposition(DrtExpression, Expression):
     def __init__(self, variable, drs):
         self.variable = variable
@@ -655,11 +649,11 @@ class DrtProposition(DrtExpression, Expression):
 
     def _pretty(self):
         drs_s = self.drs._pretty()
-        blank = ' ' * len("%s" % self.variable)
+        blank = " " * len("%s" % self.variable)
         return (
-            [blank + ' ' + line for line in drs_s[:1]]
-            + ["%s" % self.variable + ':' + line for line in drs_s[1:2]]
-            + [blank + ' ' + line for line in drs_s[2:]]
+            [blank + " " + line for line in drs_s[:1]]
+            + ["%s" % self.variable + ":" + line for line in drs_s[1:2]]
+            + [blank + " " + line for line in drs_s[2:]]
         )
 
     def visit(self, function, combinator):
@@ -671,7 +665,7 @@ class DrtProposition(DrtExpression, Expression):
         return combinator(self.variable, function(self.drs))
 
     def __str__(self):
-        return 'prop(%s, %s)' % (self.variable, self.drs)
+        return "prop(%s, %s)" % (self.variable, self.drs)
 
 
 class DrtNegatedExpression(DrtExpression, NegatedExpression):
@@ -685,10 +679,10 @@ class DrtNegatedExpression(DrtExpression, NegatedExpression):
     def _pretty(self):
         term_lines = self.term._pretty()
         return (
-            ['    ' + line for line in term_lines[:2]]
-            + ['__  ' + line for line in term_lines[2:3]]
-            + ['  | ' + line for line in term_lines[3:4]]
-            + ['    ' + line for line in term_lines[4:]]
+            ["    " + line for line in term_lines[:2]]
+            + ["__  " + line for line in term_lines[2:3]]
+            + ["  | " + line for line in term_lines[3:4]]
+            + ["    " + line for line in term_lines[4:]]
         )
 
 
@@ -712,14 +706,14 @@ class DrtLambdaExpression(DrtExpression, LambdaExpression):
         while term.__class__ == self.__class__:
             variables.append(term.variable)
             term = term.term
-        var_string = ' '.join("%s" % v for v in variables) + DrtTokens.DOT
+        var_string = " ".join("%s" % v for v in variables) + DrtTokens.DOT
         term_lines = term._pretty()
-        blank = ' ' * len(var_string)
+        blank = " " * len(var_string)
         return (
-            ['    ' + blank + line for line in term_lines[:1]]
-            + [' \  ' + blank + line for line in term_lines[1:2]]
-            + [' /\ ' + var_string + line for line in term_lines[2:3]]
-            + ['    ' + blank + line for line in term_lines[3:]]
+            ["    " + blank + line for line in term_lines[:1]]
+            + [r" \  " + blank + line for line in term_lines[1:2]]
+            + [r" /\ " + var_string + line for line in term_lines[2:3]]
+            + ["    " + blank + line for line in term_lines[3:]]
         )
 
 
@@ -742,19 +736,19 @@ class DrtBinaryExpression(DrtExpression, BinaryExpression):
         max_lines = max(len(first_lines), len(second_lines))
         first_lines = _pad_vertically(first_lines, max_lines)
         second_lines = _pad_vertically(second_lines, max_lines)
-        blank = ' ' * len(op)
+        blank = " " * len(op)
         first_second_lines = list(zip(first_lines, second_lines))
         return (
             [
-                ' ' + first_line + ' ' + blank + ' ' + second_line + ' '
+                " " + first_line + " " + blank + " " + second_line + " "
                 for first_line, second_line in first_second_lines[:2]
             ]
             + [
-                '(' + first_line + ' ' + op + ' ' + second_line + ')'
+                "(" + first_line + " " + op + " " + second_line + ")"
                 for first_line, second_line in first_second_lines[2:3]
             ]
             + [
-                ' ' + first_line + ' ' + blank + ' ' + second_line + ' '
+                " " + first_line + " " + blank + " " + second_line + " "
                 for first_line, second_line in first_second_lines[3:]
             ]
         )
@@ -782,7 +776,6 @@ class DrtEqualityExpression(DrtBinaryExpression, EqualityExpression):
         return EqualityExpression(self.first.fol(), self.second.fol())
 
 
-@python_2_unicode_compatible
 class DrtConcatenation(DrtBooleanExpression):
     """DRS of the form '(DRS + DRS)'"""
 
@@ -919,14 +912,14 @@ class DrtConcatenation(DrtBooleanExpression):
     def __str__(self):
         first = self._str_subex(self.first)
         second = self._str_subex(self.second)
-        drs = Tokens.OPEN + first + ' ' + self.getOp() + ' ' + second + Tokens.CLOSE
+        drs = Tokens.OPEN + first + " " + self.getOp() + " " + second + Tokens.CLOSE
         if self.consequent:
             return (
                 DrtTokens.OPEN
                 + drs
-                + ' '
+                + " "
                 + DrtTokens.IMP
-                + ' '
+                + " "
                 + "%s" % self.consequent
                 + DrtTokens.CLOSE
             )
@@ -961,26 +954,25 @@ class DrtApplicationExpression(DrtExpression, ApplicationExpression):
         func_args_lines = list(zip(function_lines, list(zip(*args_lines))))
         return (
             [
-                func_line + ' ' + ' '.join(args_line) + ' '
+                func_line + " " + " ".join(args_line) + " "
                 for func_line, args_line in func_args_lines[:2]
             ]
             + [
-                func_line + '(' + ','.join(args_line) + ')'
+                func_line + "(" + ",".join(args_line) + ")"
                 for func_line, args_line in func_args_lines[2:3]
             ]
             + [
-                func_line + ' ' + ' '.join(args_line) + ' '
+                func_line + " " + " ".join(args_line) + " "
                 for func_line, args_line in func_args_lines[3:]
             ]
         )
 
 
 def _pad_vertically(lines, max_lines):
-    pad_line = [' ' * len(lines[0])]
+    pad_line = [" " * len(lines[0])]
     return lines + pad_line * (max_lines - len(lines))
 
 
-@python_2_unicode_compatible
 class PossibleAntecedents(list, DrtExpression, Expression):
     def free(self):
         """Set of free variables."""
@@ -999,11 +991,11 @@ class PossibleAntecedents(list, DrtExpression, Expression):
 
     def _pretty(self):
         s = "%s" % self
-        blank = ' ' * len(s)
+        blank = " " * len(s)
         return [blank, blank, s]
 
     def __str__(self):
-        return '[' + ','.join("%s" % it for it in self) + ']'
+        return "[" + ",".join("%s" % it for it in self) + "]"
 
 
 class AnaphoraResolutionException(Exception):
@@ -1109,7 +1101,7 @@ class DrsDrawer(object):
             master = Tk()
             master.title("DRT")
 
-            font = Font(family='helvetica', size=12)
+            font = Font(family="helvetica", size=12)
 
             if size_canvas:
                 canvas = Canvas(master, width=0, height=0)
@@ -1163,8 +1155,8 @@ class DrsDrawer(object):
         :param y: the left side of the current drawing area
         :return: the bottom-rightmost point
         """
-        if isinstance(item, string_types):
-            self.canvas.create_text(x, y, anchor='nw', font=self.canvas.font, text=item)
+        if isinstance(item, str):
+            self.canvas.create_text(x, y, anchor="nw", font=self.canvas.font, text=item)
         elif isinstance(item, tuple):
             # item is the lower-right of a box
             (right, bottom) = item
@@ -1185,7 +1177,7 @@ class DrsDrawer(object):
         :param y: the left side of the current drawing area
         :return: the bottom-rightmost point
         """
-        if isinstance(item, string_types):
+        if isinstance(item, str):
             return (x + self.canvas.font.measure(item), y + self._get_text_height())
         elif isinstance(item, tuple):
             return item
@@ -1261,9 +1253,9 @@ class DrsDrawer(object):
 
         # Handle Discourse Referents
         if expression.refs:
-            refs = ' '.join("%s" % r for r in expression.refs)
+            refs = " ".join("%s" % r for r in expression.refs)
         else:
-            refs = '     '
+            refs = "     "
         (max_right, bottom) = command(refs, left, bottom)
         bottom += self.BUFFER * 2
 
@@ -1316,7 +1308,7 @@ class DrsDrawer(object):
 
             if i + 1 < len(args):
                 # since it's not the last arg, add a comma
-                right = command(DrtTokens.COMMA + ' ', right, centred_string_top)[0]
+                right = command(DrtTokens.COMMA + " ", right, centred_string_top)[0]
 
         # Handle close paren
         right = command(DrtTokens.CLOSE, right, centred_string_top)[0]
@@ -1360,7 +1352,7 @@ class DrsDrawer(object):
         )
 
         # Handle the operator
-        right = command(' %s ' % expression.getOp(), right, centred_string_top)[0]
+        right = command(" %s " % expression.getOp(), right, centred_string_top)[0]
 
         # Handle the second operand
         second_height = expression.second._drawing_height
@@ -1393,36 +1385,36 @@ class DrsDrawer(object):
 
 
 def demo():
-    print('=' * 20 + 'TEST PARSE' + '=' * 20)
+    print("=" * 20 + "TEST PARSE" + "=" * 20)
     dexpr = DrtExpression.fromstring
-    print(dexpr(r'([x,y],[sees(x,y)])'))
-    print(dexpr(r'([x],[man(x), walks(x)])'))
-    print(dexpr(r'\x.\y.([],[sees(x,y)])'))
-    print(dexpr(r'\x.([],[walks(x)])(john)'))
-    print(dexpr(r'(([x],[walks(x)]) + ([y],[runs(y)]))'))
-    print(dexpr(r'(([],[walks(x)]) -> ([],[runs(x)]))'))
-    print(dexpr(r'([x],[PRO(x), sees(John,x)])'))
-    print(dexpr(r'([x],[man(x), -([],[walks(x)])])'))
-    print(dexpr(r'([],[(([x],[man(x)]) -> ([],[walks(x)]))])'))
+    print(dexpr(r"([x,y],[sees(x,y)])"))
+    print(dexpr(r"([x],[man(x), walks(x)])"))
+    print(dexpr(r"\x.\y.([],[sees(x,y)])"))
+    print(dexpr(r"\x.([],[walks(x)])(john)"))
+    print(dexpr(r"(([x],[walks(x)]) + ([y],[runs(y)]))"))
+    print(dexpr(r"(([],[walks(x)]) -> ([],[runs(x)]))"))
+    print(dexpr(r"([x],[PRO(x), sees(John,x)])"))
+    print(dexpr(r"([x],[man(x), -([],[walks(x)])])"))
+    print(dexpr(r"([],[(([x],[man(x)]) -> ([],[walks(x)]))])"))
 
-    print('=' * 20 + 'Test fol()' + '=' * 20)
-    print(dexpr(r'([x,y],[sees(x,y)])').fol())
+    print("=" * 20 + "Test fol()" + "=" * 20)
+    print(dexpr(r"([x,y],[sees(x,y)])").fol())
 
-    print('=' * 20 + 'Test alpha conversion and lambda expression equality' + '=' * 20)
-    e1 = dexpr(r'\x.([],[P(x)])')
+    print("=" * 20 + "Test alpha conversion and lambda expression equality" + "=" * 20)
+    e1 = dexpr(r"\x.([],[P(x)])")
     print(e1)
-    e2 = e1.alpha_convert(Variable('z'))
+    e2 = e1.alpha_convert(Variable("z"))
     print(e2)
     print(e1 == e2)
 
-    print('=' * 20 + 'Test resolve_anaphora()' + '=' * 20)
-    print(resolve_anaphora(dexpr(r'([x,y,z],[dog(x), cat(y), walks(z), PRO(z)])')))
+    print("=" * 20 + "Test resolve_anaphora()" + "=" * 20)
+    print(resolve_anaphora(dexpr(r"([x,y,z],[dog(x), cat(y), walks(z), PRO(z)])")))
     print(
-        resolve_anaphora(dexpr(r'([],[(([x],[dog(x)]) -> ([y],[walks(y), PRO(y)]))])'))
+        resolve_anaphora(dexpr(r"([],[(([x],[dog(x)]) -> ([y],[walks(y), PRO(y)]))])"))
     )
-    print(resolve_anaphora(dexpr(r'(([x,y],[]) + ([],[PRO(x)]))')))
+    print(resolve_anaphora(dexpr(r"(([x,y],[]) + ([],[PRO(x)]))")))
 
-    print('=' * 20 + 'Test pretty_print()' + '=' * 20)
+    print("=" * 20 + "Test pretty_print()" + "=" * 20)
     dexpr(r"([],[])").pretty_print()
     dexpr(
         r"([],[([x],[big(x), dog(x)]) -> ([],[bark(x)]) -([x],[walk(x)])])"
@@ -1434,24 +1426,24 @@ def demo():
 
 def test_draw():
     try:
-        from six.moves.tkinter import Tk
-    except ImportError:
-        from nose import SkipTest
+        from tkinter import Tk
+    except ImportError as e:
+        import pytest
 
-        raise SkipTest("tkinter is required, but it's not available.")
+        pytest.skip("tkinter is required, but it's not available.")
 
     expressions = [
-        r'x',
-        r'([],[])',
-        r'([x],[])',
-        r'([x],[man(x)])',
-        r'([x,y],[sees(x,y)])',
-        r'([x],[man(x), walks(x)])',
-        r'\x.([],[man(x), walks(x)])',
-        r'\x y.([],[sees(x,y)])',
-        r'([],[(([],[walks(x)]) + ([],[runs(x)]))])',
-        r'([x],[man(x), -([],[walks(x)])])',
-        r'([],[(([x],[man(x)]) -> ([],[walks(x)]))])',
+        r"x",
+        r"([],[])",
+        r"([x],[])",
+        r"([x],[man(x)])",
+        r"([x,y],[sees(x,y)])",
+        r"([x],[man(x), walks(x)])",
+        r"\x.([],[man(x), walks(x)])",
+        r"\x y.([],[sees(x,y)])",
+        r"([],[(([],[walks(x)]) + ([],[runs(x)]))])",
+        r"([x],[man(x), -([],[walks(x)])])",
+        r"([],[(([x],[man(x)]) -> ([],[walks(x)]))])",
     ]
 
     for e in expressions:
@@ -1459,5 +1451,5 @@ def test_draw():
         d.draw()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     demo()
