@@ -2,7 +2,7 @@
 """
 Unit tests for nltk.classify. See also: nltk/test/classify.doctest
 """
-from nose import SkipTest
+import pytest
 from nltk import classify
 
 TRAIN = [
@@ -33,7 +33,7 @@ def assert_classifier_correct(algorithm):
             TRAIN, algorithm, trace=0, max_iter=1000
         )
     except (LookupError, AttributeError) as e:
-        raise SkipTest(str(e))
+        pytest.skip(str(e))
 
     for (px, py), featureset in zip(RESULTS, TEST):
         pdist = classifier.prob_classify(featureset)
