@@ -4,14 +4,9 @@
 Mock test for Stanford CoreNLP wrappers.
 """
 
-import sys
-from itertools import chain
-from unittest import TestCase, SkipTest
+from unittest import TestCase
+from unittest.mock import MagicMock
 
-try:
-    from unittest.mock import MagicMock
-except ImportError:
-    raise SkipTest('unittest.mock no supported in Python2')
 from nltk.tree import Tree
 from nltk.parse import corenlp
 
@@ -1088,7 +1083,7 @@ class TestParserAPI(TestCase):
 
         corenlp_parser.api_call.assert_called_once_with(
             "The quick brown fox jumps over the lazy dog",
-            properties={'ssplit.ssplit.eolonly': 'true'},
+            properties={'ssplit.eolonly': 'true'},
         )
         self.assertEqual(expected_output, parsed_data)
 
@@ -1414,6 +1409,6 @@ class TestParserAPI(TestCase):
 
         corenlp_parser.api_call.assert_called_once_with(
             "The quick brown fox jumps over the lazy dog",
-            properties={'ssplit.ssplit.eolonly': 'true'},
+            properties={'ssplit.eolonly': 'true'},
         )
         self.assertEqual(expected_output, parsed_data.tree())
