@@ -1,10 +1,9 @@
 # Natural Language Toolkit: Utility functions
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
-from __future__ import print_function
 
 import sys
 import inspect
@@ -16,57 +15,67 @@ import pydoc
 import bisect
 import os
 
-from itertools import islice, chain, combinations
+from itertools import islice, chain, combinations, tee
 from pprint import pprint
 from collections import defaultdict, deque
 from sys import version_info
 
-from six import class_types, string_types, text_type
-from six.moves.urllib.request import (build_opener, install_opener, getproxies,
-                                      ProxyHandler, ProxyBasicAuthHandler,
-                                      ProxyDigestAuthHandler,
-                                      HTTPPasswordMgrWithDefaultRealm)
+from urllib.request import (
+    build_opener,
+    install_opener,
+    getproxies,
+    ProxyHandler,
+    ProxyBasicAuthHandler,
+    ProxyDigestAuthHandler,
+    HTTPPasswordMgrWithDefaultRealm,
+)
 
 from nltk.internals import slice_bounds, raise_unorderable_types
 from nltk.collections import *
-from nltk.compat import python_2_unicode_compatible
-
 
 
 ######################################################################
 # Short usage message
 ######################################################################
 
-def usage(obj, selfname='self'):
-    str(obj) # In case it's lazy, this will load it.
 
-    if not isinstance(obj, class_types):
+def usage(obj, selfname="self"):
+    str(obj)  # In case it's lazy, this will load it.
+
+    if not isinstance(obj, type):
         obj = obj.__class__
 
-    print('%s supports the following operations:' % obj.__name__)
+    print("%s supports the following operations:" % obj.__name__)
     for (name, method) in sorted(pydoc.allmethods(obj).items()):
-        if name.startswith('_'): continue
-        if getattr(method, '__deprecated__', False): continue
+        if name.startswith("_"):
+            continue
+        if getattr(method, "__deprecated__", False):
+            continue
 
-        if sys.version_info[0] >= 3:
-            getargspec = inspect.getfullargspec
-        else:
-            getargspec = inspect.getargspec
+        getargspec = inspect.getfullargspec
         args, varargs, varkw, defaults = getargspec(method)[:4]
-        if (args and args[0]=='self' and
-            (defaults is None or len(args)>len(defaults))):
+        if (
+            args
+            and args[0] == "self"
+            and (defaults is None or len(args) > len(defaults))
+        ):
             args = args[1:]
-            name = '%s.%s' % (selfname, name)
-        argspec = inspect.formatargspec(
-            args, varargs, varkw, defaults)
-        print(textwrap.fill('%s%s' % (name, argspec),
-                            initial_indent='  - ',
-                            subsequent_indent=' '*(len(name)+5)))
+            name = "%s.%s" % (selfname, name)
+        argspec = inspect.formatargspec(args, varargs, varkw, defaults)
+        print(
+            textwrap.fill(
+                "%s%s" % (name, argspec),
+                initial_indent="  - ",
+                subsequent_indent=" " * (len(name) + 5),
+            )
+        )
+
 
 ##########################################################################
 # IDLE
 ##########################################################################
 
+
 def in_idle():
     """
     Return True if this function is run within idle.  Tkinter
@@ -79,12 +88,15 @@ def in_idle():
     :rtype: bool
     """
     import sys
-    return sys.stdin.__class__.__name__ in ('PyShell', 'RPCProxy')
+
+    return sys.stdin.__class__.__name__ in ("PyShell", "RPCProxy")
+
 
 ##########################################################################
 # PRETTY PRINTING
 ##########################################################################
 
+
 def pr(data, start=0, end=None):
     """
     Pretty print a sequence of data items
@@ -98,6 +110,7 @@ def pr(data, start=0, end=None):
     """
     pprint(list(islice(data, start, end)))
 
+
 def print_string(s, width=70):
     """
     Pretty print a string, breaking lines on whitespace
@@ -107,7 +120,8 @@ def print_string(s, width=70):
     :param width: the display width
     :type width: int
     """
-    print('\n'.join(textwrap.wrap(s, width=width)))
+    print("\n".join(textwrap.wrap(s, width=width)))
+
 
 def tokenwrap(tokens, separator=" ", width=70):
     """
@@ -120,27 +134,24 @@ def tokenwrap(tokens, separator=" ", width=70):
     :param width: the display width (default=70)
     :type width: int
     """
-    return '\n'.join(textwrap.wrap(separator.join(tokens), width=width))
+    return "\n".join(textwrap.wrap(separator.join(tokens), width=width))
 
 
 ##########################################################################
 # Python version
 ##########################################################################
 
+
 def py25():
     return version_info[0] == 2 and version_info[1] == 5
-def py26():
-    return version_info[0] == 2 and version_info[1] == 6
-def py27():
-    return version_info[0] == 2 and version_info[1] == 7
 
 
 ##########################################################################
 # Indexing
 ##########################################################################
 
-class Index(defaultdict):
 
+class Index(defaultdict):
     def __init__(self, pairs):
         defaultdict.__init__(self, list)
         for key, value in pairs:
@@ -151,6 +162,7 @@ class Index(defaultdict):
 ## Regexp display (thanks to David Mertz)
 ######################################################################
 
+
 def re_show(regexp, string, left="{", right="}"):
     """
     Return a string with markers surrounding the matched substrings.
@@ -176,21 +188,23 @@ def re_show(regexp, string, left="{", right="}"):
 
 # recipe from David Mertz
 def filestring(f):
-    if hasattr(f, 'read'):
+    if hasattr(f, "read"):
         return f.read()
-    elif isinstance(f, string_types):
-        with open(f, 'r') as infile:
+    elif isinstance(f, str):
+        with open(f, "r") as infile:
             return infile.read()
     else:
         raise ValueError("Must be called with a filename or file-like object")
 
+
 ##########################################################################
 # Breadth-First Search
 ##########################################################################
 
+
 def breadth_first(tree, children=iter, maxdepth=-1):
     """Traverse the nodes of a tree in breadth-first order.
-    (No need to check for cycles.)
+    (No check for cycles.)
     The first argument should be the tree root;
     children should be a function taking as argument a tree node
     and returning an iterator of the node's children.
@@ -207,6 +221,194 @@ def breadth_first(tree, children=iter, maxdepth=-1):
             except TypeError:
                 pass
 
+
+##########################################################################
+# Breadth-First / Depth-first Searches with Cycle Detection
+##########################################################################
+
+import warnings
+
+def acyclic_breadth_first(tree, children=iter, maxdepth=-1):
+    """Traverse the nodes of a tree in breadth-first order,
+    discarding eventual cycles.
+
+    The first argument should be the tree root;
+    children should be a function taking as argument a tree node
+    and returning an iterator of the node's children.
+    """
+    traversed = set()
+    queue = deque([(tree, 0)])
+    while queue:
+        node, depth = queue.popleft()
+        yield node
+        traversed.add(node)
+        if depth != maxdepth:
+            try:
+                for child in children(node):
+                    if child not in traversed:
+                        queue.append((child, depth + 1))
+                    else:
+                        warnings.warn('Discarded redundant search for {0} at depth {1}'.format(child, depth + 1), stacklevel=2)
+            except TypeError:
+                pass
+
+
+def acyclic_depth_first(tree, children=iter, depth=-1, cut_mark=None, traversed=None):
+    """Traverse the nodes of a tree in depth-first order,
+    discarding eventual cycles within any branch,
+    adding cut_mark (when specified) if cycles were truncated.
+
+    The first argument should be the tree root;
+    children should be a function taking as argument a tree node
+    and returning an iterator of the node's children.
+
+    Catches all cycles:
+
+    >>> import nltk
+    >>> from nltk.util import acyclic_depth_first as acyclic_tree
+    >>> wn=nltk.corpus.wordnet
+    >>> from pprint import pprint
+    >>> pprint(acyclic_tree(wn.synset('dog.n.01'), lambda s:s.hypernyms(),cut_mark='...'))
+    [Synset('dog.n.01'),
+     [Synset('canine.n.02'),
+      [Synset('carnivore.n.01'),
+       [Synset('placental.n.01'),
+        [Synset('mammal.n.01'),
+         [Synset('vertebrate.n.01'),
+          [Synset('chordate.n.01'),
+           [Synset('animal.n.01'),
+            [Synset('organism.n.01'),
+             [Synset('living_thing.n.01'),
+              [Synset('whole.n.02'),
+               [Synset('object.n.01'),
+                [Synset('physical_entity.n.01'),
+                 [Synset('entity.n.01')]]]]]]]]]]]]],
+     [Synset('domestic_animal.n.01'), "Cycle(Synset('animal.n.01'),-3,...)"]]
+    """
+    if traversed is None:
+        traversed = {tree}
+    out_tree = [tree]
+    if depth != 0:
+        try:
+            for child in children(tree):
+                if child not in traversed:
+#                   Recurse with a common "traversed" set for all children:
+                    traversed.add(child)
+                    out_tree += [acyclic_depth_first(child, children, depth - 1, cut_mark, traversed)]
+                else:
+                    warnings.warn('Discarded redundant search for {0} at depth {1}'.format(child, depth - 1), stacklevel=3)
+                    if cut_mark:
+                        out_tree += ['Cycle({0},{1},{2})'.format(child, depth - 1, cut_mark)]
+        except TypeError:
+            pass
+    elif cut_mark:
+        out_tree += [cut_mark]
+    return out_tree
+
+
+def acyclic_branches_depth_first(tree, children=iter, depth=-1, cut_mark=None, traversed=None):
+    """Traverse the nodes of a tree in depth-first order,
+    discarding eventual cycles within the same branch,
+    but keep duplicate pathes in different branches.
+    Add cut_mark (when defined) if cycles were truncated.
+
+    The first argument should be the tree root;
+    children should be a function taking as argument a tree node
+    and returning an iterator of the node's children.
+
+    Catches only only cycles within the same branch,
+    but keeping cycles from different branches:
+
+    >>> import nltk
+    >>> from nltk.util import acyclic_branches_depth_first as tree
+    >>> wn=nltk.corpus.wordnet
+    >>> from pprint import pprint
+    >>> pprint(tree(wn.synset('certified.a.01'), lambda s:s.also_sees(), cut_mark='...', depth=4))
+    [Synset('certified.a.01'),
+     [Synset('authorized.a.01'),
+      [Synset('lawful.a.01'),
+       [Synset('legal.a.01'),
+        "Cycle(Synset('lawful.a.01'),0,...)",
+        [Synset('legitimate.a.01'), '...']],
+       [Synset('straight.a.06'),
+        [Synset('honest.a.01'), '...'],
+        "Cycle(Synset('lawful.a.01'),0,...)"]],
+      [Synset('legitimate.a.01'),
+       "Cycle(Synset('authorized.a.01'),1,...)",
+       [Synset('legal.a.01'),
+        [Synset('lawful.a.01'), '...'],
+        "Cycle(Synset('legitimate.a.01'),0,...)"],
+       [Synset('valid.a.01'),
+        "Cycle(Synset('legitimate.a.01'),0,...)",
+        [Synset('reasonable.a.01'), '...']]],
+      [Synset('official.a.01'), "Cycle(Synset('authorized.a.01'),1,...)"]],
+     [Synset('documented.a.01')]]
+    """
+    if traversed is None:
+        traversed = {tree}
+    out_tree = [tree]
+    if depth != 0:
+        try:
+            for child in children(tree):
+                if child not in traversed:
+#                   Recurse with a different "traversed" set for each child:
+                    out_tree += [acyclic_branches_depth_first(child, children, depth - 1, cut_mark, traversed.union({child}))]
+                else:
+                    warnings.warn('Discarded redundant search for {0} at depth {1}'.format(child, depth - 1), stacklevel=3)
+                    if cut_mark:
+                        out_tree += ['Cycle({0},{1},{2})'.format(child, depth - 1, cut_mark)]
+        except TypeError:
+            pass
+    elif cut_mark:
+        out_tree += [cut_mark]
+    return out_tree
+
+
+def acyclic_dic2tree(node, dic):
+    """Convert acyclic dictionary 'dic', where the keys are nodes, and the
+    values are lists of children, to output tree suitable for pprint(),
+    starting at root 'node', with subtrees as nested lists."""
+    return [node] + [acyclic_dic2tree(child, dic) for child in dic[node]]
+
+
+def unweighted_minimum_spanning_tree(tree, children=iter):
+    """
+    Output a Minimum Spanning Tree (MST) of an unweighted graph,
+    by traversing the nodes of a tree in breadth-first order,
+    discarding eventual cycles.
+
+    The first argument should be the tree root;
+    children should be a function taking as argument a tree node
+    and returning an iterator of the node's children.
+
+    >>> import nltk
+    >>> from nltk.util import unweighted_minimum_spanning_tree as mst
+    >>> wn=nltk.corpus.wordnet
+    >>> from pprint import pprint
+    >>> pprint(mst(wn.synset('bound.a.01'), lambda s:s.also_sees()))
+    [Synset('bound.a.01'),
+     [Synset('unfree.a.02'),
+      [Synset('confined.a.02')],
+      [Synset('dependent.a.01')],
+      [Synset('restricted.a.01'), [Synset('classified.a.02')]]]]
+    """
+    traversed = set()             # Empty set of traversed nodes
+    queue = deque([tree])         # Initialize queue
+    agenda = {tree}               # Set of all nodes ever queued
+    mstdic = {}                   # Empty MST dictionary
+    while queue:
+        node = queue.popleft()    # Node is not yet in the MST dictionary,
+        mstdic[node]=[]           # so add it with an empty list of children
+        if node not in traversed: # Avoid cycles
+            traversed.add(node)
+            for child in children(node):
+                if child not in agenda:            # Queue nodes only once
+                    mstdic[node].append(child)     # Add child to the MST
+                    queue.append(child)            # Add child to queue
+                    agenda.add(child)
+    return acyclic_dic2tree(tree, mstdic)
+
+
 ##########################################################################
 # Guess Character Encoding
 ##########################################################################
@@ -214,6 +416,7 @@ def breadth_first(tree, children=iter, maxdepth=-1):
 # adapted from io.py in the docutils extension module (http://docutils.sourceforge.net)
 # http://www.pyzine.com/Issue008/Section_Articles/article_Encodings.html
 
+
 def guess_encoding(data):
     """
     Given a byte string, attempt to decode it.
@@ -229,7 +432,7 @@ def guess_encoding(data):
     """
     successful_encoding = None
     # we make 'utf-8' the first encoding
-    encodings = ['utf-8']
+    encodings = ["utf-8"]
     #
     # next we add anything we can learn from the locale
     try:
@@ -246,14 +449,14 @@ def guess_encoding(data):
         pass
     #
     # we try 'latin-1' last
-    encodings.append('latin-1')
+    encodings.append("latin-1")
     for enc in encodings:
         # some of the locale calls
         # may have returned None
         if not enc:
             continue
         try:
-            decoded = text_type(data, enc)
+            decoded = str(data, enc)
             successful_encoding = enc
 
         except (UnicodeError, LookupError):
@@ -261,30 +464,35 @@ def guess_encoding(data):
         else:
             break
     if not successful_encoding:
-         raise UnicodeError(
-        'Unable to decode input data.  Tried the following encodings: %s.'
-        % ', '.join([repr(enc) for enc in encodings if enc]))
+        raise UnicodeError(
+            "Unable to decode input data. "
+            "Tried the following encodings: %s."
+            % ", ".join([repr(enc) for enc in encodings if enc])
+        )
     else:
-         return (decoded, successful_encoding)
+        return (decoded, successful_encoding)
 
 
 ##########################################################################
 # Remove repeated elements from a list deterministcally
 ##########################################################################
 
+
 def unique_list(xs):
     seen = set()
     # not seen.add(x) here acts to make the code shorter without using if statements, seen.add(x) always returns None.
     return [x for x in xs if x not in seen and not seen.add(x)]
 
+
 ##########################################################################
 # Invert a dictionary
 ##########################################################################
 
+
 def invert_dict(d):
     inverted_dict = defaultdict(list)
     for key in d:
-        if hasattr(d[key], '__iter__'):
+        if hasattr(d[key], "__iter__"):
             for term in d[key]:
                 inverted_dict[term].append(key)
         else:
@@ -297,6 +505,7 @@ def invert_dict(d):
 # The graph is represented as a dictionary of sets
 ##########################################################################
 
+
 def transitive_closure(graph, reflexive=False):
     """
     Calculate the transitive closure of a directed graph,
@@ -347,21 +556,28 @@ def invert_graph(graph):
     return inverted
 
 
-
 ##########################################################################
 # HTML Cleaning
 ##########################################################################
 
+
 def clean_html(html):
-    raise NotImplementedError ("To remove HTML markup, use BeautifulSoup's get_text() function")
+    raise NotImplementedError(
+        "To remove HTML markup, use BeautifulSoup's get_text() function"
+    )
+
 
 def clean_url(url):
-    raise NotImplementedError ("To remove HTML markup, use BeautifulSoup's get_text() function")
+    raise NotImplementedError(
+        "To remove HTML markup, use BeautifulSoup's get_text() function"
+    )
+
 
 ##########################################################################
 # FLATTEN LISTS
 ##########################################################################
 
+
 def flatten(*args):
     """
     Flatten a list.
@@ -376,7 +592,8 @@ def flatten(*args):
 
     x = []
     for l in args:
-        if not isinstance(l, (list, tuple)): l = [l]
+        if not isinstance(l, (list, tuple)):
+            l = [l]
         for item in l:
             if isinstance(item, (list, tuple)):
                 x.extend(flatten(item))
@@ -384,12 +601,20 @@ def flatten(*args):
                 x.append(item)
     return x
 
+
 ##########################################################################
 # Ngram iteration
 ##########################################################################
 
-def pad_sequence(sequence, n, pad_left=False, pad_right=False,
-                 left_pad_symbol=None, right_pad_symbol=None):
+
+def pad_sequence(
+    sequence,
+    n,
+    pad_left=False,
+    pad_right=False,
+    left_pad_symbol=None,
+    right_pad_symbol=None,
+):
     """
     Returns a padded sequence of items before ngram extraction.
 
@@ -416,15 +641,16 @@ def pad_sequence(sequence, n, pad_left=False, pad_right=False,
     """
     sequence = iter(sequence)
     if pad_left:
-        sequence = chain((left_pad_symbol,) * (n-1), sequence)
+        sequence = chain((left_pad_symbol,) * (n - 1), sequence)
     if pad_right:
-        sequence = chain(sequence, (right_pad_symbol,) * (n-1))
+        sequence = chain(sequence, (right_pad_symbol,) * (n - 1))
     return sequence
 
+
 # add a flag to pad the sequence so we get peripheral ngrams?
 
-def ngrams(sequence, n, pad_left=False, pad_right=False,
-           left_pad_symbol=None, right_pad_symbol=None):
+
+def ngrams(sequence, n, **kwargs):
     """
     Return the ngrams generated from a sequence of items, as an iterator.
     For example:
@@ -460,17 +686,17 @@ def ngrams(sequence, n, pad_left=False, pad_right=False,
     :type right_pad_symbol: any
     :rtype: sequence or iter
     """
-    sequence = pad_sequence(sequence, n, pad_left, pad_right,
-                            left_pad_symbol, right_pad_symbol)
+    sequence = pad_sequence(sequence, n, **kwargs)
+    
+    # Creates the sliding window, of n no. of items.
+    # `iterables` is a tuple of iterables where each iterable is a window of n items.
+    iterables = tee(sequence, n)
+
+    for i, sub_iterable in enumerate(iterables): # For each window,
+        for _ in range(i):                       # iterate through every order of ngrams
+            next(sub_iterable, None)             # generate the ngrams within the window.
+    return zip(*iterables) # Unpack and flattens the iterables.
 
-    history = []
-    while n > 1:
-        history.append(next(sequence))
-        n -= 1
-    for item in sequence:
-        history.append(item)
-        yield tuple(history)
-        del history[0]
 
 def bigrams(sequence, **kwargs):
     """
@@ -491,6 +717,7 @@ def bigrams(sequence, **kwargs):
     for item in ngrams(sequence, 2, **kwargs):
         yield item
 
+
 def trigrams(sequence, **kwargs):
     """
     Return the trigrams generated from a sequence of items, as an iterator.
@@ -510,30 +737,66 @@ def trigrams(sequence, **kwargs):
     for item in ngrams(sequence, 3, **kwargs):
         yield item
 
-def everygrams(sequence, min_len=1, max_len=-1, **kwargs):
+
+def everygrams(sequence, min_len=1, max_len=-1, pad_left=False, pad_right=False, **kwargs):
     """
     Returns all possible ngrams generated from a sequence of items, as an iterator.
 
         >>> sent = 'a b c'.split()
-        >>> list(everygrams(sent))
-        [('a',), ('b',), ('c',), ('a', 'b'), ('b', 'c'), ('a', 'b', 'c')]
-        >>> list(everygrams(sent, max_len=2))
-        [('a',), ('b',), ('c',), ('a', 'b'), ('b', 'c')]
 
-    :param sequence: the source data to be converted into trigrams
+    New version outputs for everygrams.
+        >>> list(everygrams(sent))
+        [('a',), ('a', 'b'), ('a', 'b', 'c'), ('b',), ('b', 'c'), ('c',)]
+
+    Old version outputs for everygrams.
+        >>> sorted(everygrams(sent), key=len)
+        [('a',), ('b',), ('c',), ('a', 'b'), ('b', 'c'), ('a', 'b', 'c')]
+
+        >>> list(everygrams(sent, max_len=2))
+        [('a',), ('a', 'b'), ('b',), ('b', 'c'), ('c',)]
+
+    :param sequence: the source data to be converted into ngrams. If max_len is
+        not provided, this sequence will be loaded into memory
     :type sequence: sequence or iter
     :param min_len: minimum length of the ngrams, aka. n-gram order/degree of ngram
     :type  min_len: int
     :param max_len: maximum length of the ngrams (set to length of sequence by default)
     :type  max_len: int
+    :param pad_left: whether the ngrams should be left-padded
+    :type pad_left: bool
+    :param pad_right: whether the ngrams should be right-padded
+    :type pad_right: bool
     :rtype: iter(tuple)
     """
 
+    # Get max_len for padding.
     if max_len == -1:
-        max_len = len(sequence)
-    for n in range(min_len, max_len+1):
-        for ng in ngrams(sequence, n, **kwargs):
-            yield ng
+        try:
+            max_len = len(sequence)
+        except TypeError:
+            sequence = list(sequence)
+            max_len = len(sequence)
+
+    # Pad if indicated using max_len.
+    sequence = pad_sequence(sequence, max_len, pad_left, pad_right, **kwargs)
+
+    # Sliding window to store grams.
+    history = list(islice(sequence, max_len))
+
+    # Yield ngrams from sequence.
+    while history:
+        for ngram_len in range(min_len, len(history)+1):
+            yield tuple(history[:ngram_len])
+
+        # Append element to history if sequence has more items.
+        try:
+            history.append(next(sequence))
+        except StopIteration:
+            pass
+
+        del history[0]
+
+
 
 def skipgrams(sequence, n, k, **kwargs):
     """
@@ -557,7 +820,7 @@ def skipgrams(sequence, n, k, **kwargs):
     """
 
     # Pads the sequence as desired by **kwargs.
-    if 'pad_left' in kwargs or 'pad_right' in kwargs:
+    if "pad_left" in kwargs or "pad_right" in kwargs:
         sequence = pad_sequence(sequence, n, **kwargs)
 
     # Note when iterating through the ngrams, the pad_right here is not
@@ -572,6 +835,7 @@ def skipgrams(sequence, n, k, **kwargs):
                 continue
             yield head + skip_tail
 
+
 ######################################################################
 # Binary Search in a File
 ######################################################################
@@ -588,12 +852,12 @@ def binary_search_file(file, key, cache={}, cacheDepth=-1):
     :param key: the identifier we are searching for.
     """
 
-    key = key + ' '
+    key = key + " "
     keylen = len(key)
     start = 0
     currentDepth = 0
 
-    if hasattr(file, 'name'):
+    if hasattr(file, "name"):
         end = os.stat(file.name).st_size - 1
     else:
         file.seek(0, 2)
@@ -612,13 +876,14 @@ def binary_search_file(file, key, cache={}, cacheDepth=-1):
             while True:
                 file.seek(max(0, middle - 1))
                 if middle > 0:
-                    file.readline()
+                    file.discard_line()
                 offset = file.tell()
                 line = file.readline()
-                if line != "": break
+                if line != "":
+                    break
                 # at EOF; try to find start of the last line
-                middle = (start + middle)//2
-                if middle == end -1:
+                middle = (start + middle) // 2
+                if middle == end - 1:
                     return None
             if currentDepth < cacheDepth:
                 cache[middle] = (offset, line)
@@ -644,11 +909,13 @@ def binary_search_file(file, key, cache={}, cacheDepth=-1):
 
     return None
 
+
 ######################################################################
 # Proxy configuration
 ######################################################################
 
-def set_proxy(proxy, user=None, password=''):
+
+def set_proxy(proxy, user=None, password=""):
     """
     Set the HTTP proxy for Python to download through.
 
@@ -661,24 +928,21 @@ def set_proxy(proxy, user=None, password=''):
         authentication.
     :param password: The password to authenticate with.
     """
-    from nltk import compat
-
     if proxy is None:
         # Try and find the system proxy settings
         try:
-            proxy = getproxies()['http']
-        except KeyError:
-            raise ValueError('Could not detect default proxy settings')
+            proxy = getproxies()["http"]
+        except KeyError as e:
+            raise ValueError("Could not detect default proxy settings") from e
 
     # Set up the proxy handler
-    proxy_handler = ProxyHandler({'https': proxy, 'http': proxy})
+    proxy_handler = ProxyHandler({"https": proxy, "http": proxy})
     opener = build_opener(proxy_handler)
 
     if user is not None:
         # Set up basic proxy authentication if provided
         password_manager = HTTPPasswordMgrWithDefaultRealm()
-        password_manager.add_password(realm=None, uri=proxy, user=user,
-                passwd=password)
+        password_manager.add_password(realm=None, uri=proxy, user=user, passwd=password)
         opener.add_handler(ProxyBasicAuthHandler(password_manager))
         opener.add_handler(ProxyDigestAuthHandler(password_manager))
 
@@ -705,22 +969,24 @@ def elementtree_indent(elem, level=0):
     :return:  Contents of elem indented to reflect its structure
     """
 
-    i = "\n" + level*"  "
+    i = "\n" + level * "  "
     if len(elem):
         if not elem.text or not elem.text.strip():
             elem.text = i + "  "
         for elem in elem:
-            elementtree_indent(elem, level+1)
+            elementtree_indent(elem, level + 1)
         if not elem.tail or not elem.tail.strip():
             elem.tail = i
     else:
         if level and (not elem.tail or not elem.tail.strip()):
             elem.tail = i
 
+
 ######################################################################
 # Mathematical approximations
 ######################################################################
 
+
 def choose(n, k):
     """
     This function is a fast way to calculate binomial coefficients, commonly
@@ -749,3 +1015,29 @@ def choose(n, k):
         return ntok // ktok
     else:
         return 0
+
+
+######################################################################
+# Iteration utilities
+######################################################################
+
+
+def pairwise(iterable):
+    """s -> (s0,s1), (s1,s2), (s2, s3), ..."""
+    a, b = tee(iterable)
+    next(b, None)
+    return zip(a, b)
+
+######################################################################
+# Parallization.
+######################################################################
+
+
+def parallelize_preprocess(func, iterator, processes, progress_bar=False):
+    from tqdm import tqdm
+    from joblib import Parallel, delayed
+
+    iterator = tqdm(iterator) if progress_bar else iterator
+    if processes <= 1:
+        return map(func, iterator)
+    return Parallel(n_jobs=processes)(delayed(func)(line) for line in iterator)
